from netdisco.util.worklet import context as c
from netdisco.util.ssh import net_connect


def main():
    command = 'arp -a'
    with net_connect:
        output = net_connect.send_command(command, use_textfsm=True)

    arps = []
    if output is not None:
        # debug(output)
        for record in output:
            arps.append(
                {'dns': record['rev_dns'], 'ip': record['ip_address'], 'mac': record['mac_address']}
            )

    # debug(arps)
    if len(arps) > 0:
        c.stash.set('arps', arps)
        c.status.done('Gathered arp caches from ' + c.job.device)
    else:
        c.status.info('No arp cache retrieved from ' + c.job.device)


if __name__ == '__main__':
    main()



"""
netdisco.util.config
~~~~~~~~~~~~~~~~~~~~

Access to Netdisco runtime configuration.
"""

import os
import json

ND2_CONFIGURATION = json.loads(os.environ.get('ND2_CONFIGURATION', '{"log":"warning"}'))


def setting(name):
    if name in ND2_CONFIGURATION:
        return ND2_CONFIGURATION[name]
    else:
        return None



import yamllint
from yamllint.config import YamlLintConfig
from netdisco.util.worklet import debug, context as c


def main():
    yaml_config = YamlLintConfig('{extends: relaxed, rules: {empty-lines: disable}}')
    target = c.job.subaction or c.stash.get('file_to_lint')
    debug('target: ' + target)

    found_issues = False
    for p in yamllint.linter.run(open(target), yaml_config):
        found_issues = True
        debug(f'{p.line}: ({p.rule}) {p.desc}')

    if found_issues:
        c.status.error('Lint errors, view with --debug')
    else:
        c.status.done('Linted OK')


if __name__ == '__main__':
    main()
